@@ -460,7 +460,7 @@ ncscreen_message103( message103_t * message103 )
 		  hr, min, sec );
 
 	  /* Return to main screen if no error at setting the hw clock */
-	  if( set_hwclock( utc ) != -1 ) set_mode( MD_MAINSCREEN );
+	  if( set_hwclock( utc ) != ERROR ) set_mode( MD_MAINSCREEN );
 	}
 	else
 	  set_mode( MD_UTCINVALID | MD_PROGHALT);
@@ -690,7 +690,7 @@ ncscreen_status(void)
   } /* End switch ( message_protocol() ) */
 
   /* If errno is not set, use mode flags to display errors */
-  if( error_num() == 0 )
+  if( error_num() == SUCCESS )
   {
 	if( isModeSet(MD_READFAIL | MD_WRITEFAIL) )
 	{
@@ -718,7 +718,7 @@ ncscreen_status(void)
   {
 	attrset( ALARM );
 	mvaddstr( 21, 2, strerror( error_num() ) );
-  } /* End if( error_num == 0) */
+  } /* End if( error_num == SUCCESS) */
 
   clear_error(); /* Clear error_num after display */
 
